print CLIENT <<EOF
<A NAME="DNS_vulnerabilities">
<HTML>
<HEAD>
<TITLE>Tutorial - DNS Vulnerabilities</TITLE>
</HEAD>
<BODY>

<H1>DNS Vulnerabilities</H1>

<H3>Impact</H3>

There are numerous vulnerabilities in Domain Name Servers (DNS) that are
documented in the 
<A HREF="http://www.cert.org/advisories">CERT Advisories</A>.
The two principal areas are:
<ul>
<li>A remote intruder can gain root-level access to your name server. 

<li>A remote intruder is able to disrupt normal operation of your name server. 
</ul>

<H3>Problems</H3>

BIND 4.9 releases prior to BIND 4.9.7 and BIND 8 releases prior to 8.1.2 do 
not properly bounds check a memory copy when responding to an inverse query 
request. An improperly or maliciously formatted inverse query on a TCP 
stream can crash the server or allow an attacker to gain root privileges. 
<P>
BIND 4.9 releases prior to BIND 4.9.7 and BIND 8 releases prior to 8.1.2 do 
not properly bounds check many memory references in the server and the 
resolver. An improperly or maliciously formatted DNS message can cause the 
server to read from invalid memory locations, yielding garbage record data 
or crashing the server. Many DNS utilities that process DNS messages 
(e.g., dig, nslookup) also fail to do proper bounds checking. 
 
BIND 4.9 releases and BIND 8 release prior to 8.2.2 Patch 3 have a variety of 
security issues.  You can review them and <A HREF="http://www.isc.org/products/BIND/bind-security-19991108.html">BIND Security</A>.

<H3>Resolutions</H3>

To resolve these problems, upgrade to 
<A HREF="http://www.isc.org/new-bind.html">BIND 8.2.2.</A>  If this is not 
feasible, you can apply a patch, or use a workaround, described in the
various
<A HREF = "http://www.cert.org/advisories">CERT Advisories</a>.
</BODY>
</HTML>
<HR>
<A NAME="FrontPage_access">
<HTML>
<HEAD>
<TITLE>Tutorial - Common Gateway Interface (CGI) Access</TITLE>
</HEAD>
<BODY>

<H1>Common Gateway Interface Interface 
(CGI) Access</H1>

<H3>Impact</H3>

Older Web server implementations contained CGI scripts that would allow 
the user to access files and execute commands on the server.  However, 
these scripts did not adequately address security and are exploited to 
(1) download system and user files, (2) execute commands as the Web 
administrator and (3) contaminate Web pages.
<P>
Several problems with Microsoft Internet Information Servers (IIS) are
also addressed here.  Many FrontPage installations allow the malicious
user to read, delete, and modify pages on an IIS (and other FrontPage 
supported) sites.  Also, many IIS distributions have sample programs
enabled that enable the hacker to read, delete, or modify web pages.
<P>
A recent (1999) exploit in ColdFusion extensions could enable the malicious
user to alter web pages.

<H3>Background</H3>

Security vulnerabilities have been reported in numerous CGI scripts, including 
webdist.cgi, handler.cgi, phf, htmlscript, view-source, and
php.cgi.  These scripts can provide the malicious user access to data and 
programs on the Web server host. 
<P>
Similar vulnerabilities may be present with IIS servers (codebrws and 
FrontPage) as well as third part add-ons such as ColdFusion. In addition, 
Microsoft's RDS facility is often exploited through IIS.

<H3>Resolution</H3>

Vendor and Web server patches and workarounds to protect against this 
vulnerability are available from Silicon Graphics Inc., the Apache Group,  
NCSA, Microsoft, and Allaire (ColdFusion) and should be applied as soon as 
possible.  A workaround to this problem is to remove the execute permissions 
on the offending scripts to prevent their exploitation.  If the scripts are 
not required, they should be removed from the system.
<p>
<H3>Where can I read more about this?</H3>

You may read more about this vulnerability in 
<A HREF="http://www.cert.org/advisories/CA-97.12.webdist.html">
CERT Advisory 97.12</a>.  For those interested in reading more about 
general WWW security and secure CGI programming, visit the 
<A HREF="http://www-genome.wi.mit.edu/WWW/faqs/www-security-faq.html">
World Wide Web Security FAQ</a>.
<P>
For a description of the IIS and ColdFusion exploits, go to
<A HREF="http://www.phrack.com">Phrack Magazine</A>. Information on
Frontpage can be found at 
<A HREF="http://support.microsoft.com/support/frontpage/Q152306/default.asp">
Microsoft</A> and information on RDS can be found at
<A HREF="http://www.attrition.org/security/advisory/rfp/rfp.9907.msadcs">
RDS</A>.
</BODY>
</HTML>
<HR>
<A NAME="NFS_export_to_unprivileged_programs">
<HTML>
<HEAD>
<TITLE>Tutorial - Unprivileged NFS access</TITLE>
</HEAD>
<BODY>

<H1>Unprivileged NFS access</H1>

<HR>

<H3>Summary</H3>

NFS server executes requests from unprivileged user programs.

<H3>Impact</H3>

A malicious user can execute NFS file access requests on behalf of any user.

<H3>Background</H3>

When an NFS client host wants to access a remote file or directory, its
operating system sends a request to the NFS server. The request
specifies, among others, a file identifier, the operation (read, write,
change permission, etc.), and the identity of the user on whose behalf
the operation is to be done.

<p>

By default, the user identity is specified with the UNIX numeric user
and group ids.  With this scheme, also called AUTH_UNIX, the server
simply believes anything that the client sends it.

<H3>The problem</H3>

An NFS request is nothing but a network message.  Any user can run a
program that generates arbitrary NFS requests.  Such programs have been
available for several years, and writing them does not require unusual
programming skills.

<p>

When an NFS server accepts requests with AUTH_UNIX authentication from
unprivileged user programs, a malicious user can execute file access
requests on behalf of any user.  Reason: with AUTH_UNIX authentication,
the user identity is nothing but a few user and group ID numbers in a
network message.

<H3>Fix</H3>

The fix is to avoid AUTH_UNIX authentication and to use something that
involves cryptography. For example, secure NFS with DES or Kerberos
credentials. Unfortunately, many NFS implementations support AUTH_UNIX
authentication only. Consult your system documentation.

<p>

A partial, but more common, solution is to configure the NFS server,
and where possible, the mount daemon, to accept requests only from
privileged system programs (such as UNIX kernels), and to reject NFS
requests that are sent by unprivileged user programs.

<p>

<ul>

<li>SunOS 4 administrators modify <tt>/etc/rc.local</tt>

<ul>

<li><tt>rpc.mountd</tt> (no -n option)

<li><tt>echo "nfs_portmon/W1" | adb -w /vmunix /dev/kmem</tt>

</ul>

<p>

<li>SunOS 5 administrators modify <tt>/etc/system</tt>

<ul>

<li><tt>set nfs:nfs_portmon = 1</tt>

</ul>

</ul>

<p>

On other systems, the mountd command-line options differ, and the
kernel variable may be called <em>nfsportmon</em> or something
similar.

<p>

<strong>Note: rejecting NFS requests from unprivileged user programs
does not protect your servers against malicious superusers or against
malicious PC programs.</strong>

<H3>Other tips</H3>

<ul>

<li>Where practical, export file systems read-only.

<li>Consider blocking ports 2049 (nfs) and 111 (portmap) on your
routers.

</ul>
</BODY>
</HTML>
<HR>
<A NAME="NFS_export_via_portmapper">
<HTML>
<HEAD>
<TITLE>Tutorial - Portmapper exports</TITLE>
</HEAD>
<BODY>

<H1>Portmapper exports</H1>

<HR>

<H3>Summary</H3>

NFS file exports via the portmapper.

<H3>Impact</H3>

NFS export restrictions can be bypassed.

<H3>Background</H3>

In order to perform operations via the NFS network file system
protocol, a client host sends NFS requests to the NFS server daemon
with:

<ul>

<li>an NFS file handle that specifies the target of the operation,

<li>the operation (lookup, read, write, change permissions),

<li>the user on whose behalf the request is sent.

</ul>

When an NFS client host wants to access a remote file system for the
first time, it first needs to obtain an NFS file handle. To this end,
the client host sends an mount request to the server's mount
daemon.  The server's mount daemon verifies that the client host has
permission to access the requested file system.  When the mount daemon
grants access, it sends a (directory) file handle back to the NFS
client.

<H3>The problem</H3>

For efficiency reasons, most NFS export restrictions are enforced by
the mount daemon. Individual file access operations are handled by the
NFS daemon, and the origin of such requests is examined only in
special cases such as remote superuser access.

<p>

Instead of talking directly to the mount daemon, a malicious NFS
client can ask the server's portmapper daemon to forward the request to
the mount daemon.  When the mount daemon receives the request from
the portmapper, the mount daemon will believe that the request comes
from the file server, and not from the malicious client.

<p>

When the file server exports file systems to itself (for example,
because the server is a netgroup member) the mount daemon grants access
and replies with a file handle.  The portmapper forwards the handle to
the malicious client. From now on, the client can talk directly to the
server's NFS daemon to access the directory and all files below it.

<H3>Fix</H3>

Run a portmapper (or rpcbind program in case of System V.4) that does
not forward mount etc. requests. Consult your vendor's patch list.
See also: 
<a href="ftp://ftp.cert.org/pub/cert_advisories/CA-94:15.NFS.Vulnerabilities">
Cert Advisory 94:15</a>.

<H3>Other tips</H3>

<ul>

<li>Export file systems read-only where possible.

<li>Consider blocking ports 2049 (nfs) and 111 (portmap) on your
routers.

</ul>
</BODY>
</HTML>
<HR>
<A NAME="NIS_password_file_access">
<HTML>
<HEAD>
<TITLE>Tutorial - NIS password file access</TITLE>
</HEAD>
<BODY>

<H1>NIS password file access</H1>

<HR>

<H3>Summary</H3>

NIS password file access by arbitrary hosts.

<H3>Impact</H3>

Allows automated password guessing attacks.

<H3>Background</H3>

The NIS (Network Information Service) implements network-wide access to
administrative information. Examples of databases (also called NIS maps)
that are shared via NIS:

<ul>

<li>the password file that describes what users have access to the system,

<li>the table with names and addresses of hosts on the network, 

<li>electronic mail aliases.

</ul>

NIS databases are organized in domains.  One NIS server can serve
multiple NIS domains. In order to perform a query, a client sends a
request to a NIS server and specifies 

<ul>

<li>a NIS domain name, 

<li>the name of the database (NIS map) to be searched, 

<li>a search key.

</ul>

<H3>The problem</H3>

Many NIS implementations provide no access control. Every host that
asks for information will receive a reply. In order to perform a query,
one needs to know the server's NIS domain name. Often, this name is
easy to guess, or it can be obtained via the <em>bootparam</em>
network service.

<p>

When the local network is accessible from other networks, a remote
intruder can collect password file information and run a password
guessing program.  Many people (including
<a href="ftp://coast.cs.purdue.edu/pub/doc/passwords/Dan_Klein_password.ps.Z">
Dan Klein</a>) have demonstrated that people tend to choose passwords that
are easy to guess.

<H3>Fix</H3>

<ul>

<li>Several vendors have added access control to their <em> ypserv</em>
implementation. Check your system documentation or vendor patch
list. The control file is sometimes called <em>securenets</em>.

</ul>

<H3>Workarounds</H3>

<ul>

<li>Run a <a href="ftp://ftp.win.tue.nl/pub/security/index.html">portmapper
</a>with access control.

</ul>

<H3>Other tips</H3>

<ul>

<li>Consider blocking ports 111 (portmap) on your network gateway.
This makes attacks on NIS and NFS mount daemons much harder.

<li>Enforce a policy for choosing passwords by installing an
alternative <em>passwd</em> command, for example
<a href="ftp://coast.cs.purdue.edu/pub/tools/unix/anlpasswd">anlpasswd</a>.

<li>See the
<a href="http://www.clark.net/pub/arccom/stuff/admin_guide_to_cracking.html#nis-passwords">Admin
Guide to Cracking</a> for an example of why this is a problem.

</ul>
</BODY>
</HTML>
<HR>
<A NAME="Possible_DoS_problem">
<HTML>
<HEAD>
<TITLE>Tutorial - Possible DoS (fraggle) Problem</TITLE>
</HEAD>
<BODY>

<H1>Possible DoS (fraggle) Problem</H1>

<H3>Impact</H3>

Your machine may be vulnerable to certain types of Denial of Service attacks (<b>Fraggle</b>, 
<b>Smurf</b> and <b>Papasmurf</b>).  These DoS attacks affect Windows 95 and Windows NT 
4.0 machines.  These attacks will cause a loss of connectivity to the Internet and 
may slow network activity to a crawl.

<H3>Background</H3>

The <b>Fraggle</b> attack, and other attacks of this type, such as <b>Smurf</b> and <b>Papasmurf</b>, is the most 
recent in the category of network-level attacks against hosts.  <b>Smurf</b>, and <b>Smurf</b> type attacks, begin 
when a hacker sends a large amount of 
<A HREF = "http://www.telstra.com.au/pub/docs/security/800-10/node19.html">ICMP</a> 
echo (ping) traffic to a subnet broadcast address (
say, for instance, xxx.xxx.xxx.255 - the 255 number marks this as a broadcast address).  This 
traffic will have a spoofed return address.  This spoofed address will be the address of the 
intended victim of the attack.  When individual machines on the network receive the ICMP echo 
requests, they will reply with an echo reply.  These 
replies will all go to the address spoofed in the original ICMP echo requests.  On networks with 
a large number of systems, the traffic generated could be voluminous indeed.  The system which 
is the victim of the attack (as indicated by the spoofed IP address) quickly becomes overwhelmed 
by incoming traffic, and will almost certainly lose connectivity to the Internet.

<p>

Actually, there are two victims of this type of attack when it is run:  the network which is exploited 
to generate the ICMP traffic (called the intermediary, or "helper" network) and the system indicated by the spoofed IP 
address.

<p>

The <b>Fraggle</b> DoS attack is essentially based on the same concept as the <b>Smurf</b> 
attack (namely that generating huge amounts of network traffic will 
disable a machine or cause it to lose connectivity to the Internet), 
but uses UDP instead of ICMP.  Although it is not as serious as some 
other attacks of this type, it will still generate a huge amount of network 
traffic.  Here is how it works:  a hacker is armed with a list of broadcast 
addresses, to which he/she sends spoofed UDP packets.  Usually the packets 
are directed to port 7 on the target machines, which is the echo port.  Other times, 
it is directed to the chargen port (a port that generates a number of characters 
when queried).  Sometimes a hacker is able to set up a loop between the 
echo and chargen ports, generating all that much more network traffic 
(this attack generally works on NT boxes).

<p>

The result of this attack is, as stated earlier, a massive amount of traffic 
on the network.  Whole networks may crawl to a stop and individual systems may 
lose connectivity to the Internet and/or, in some cases, crash.


<h3>The Problem</h3>

The <b>Fraggle</b> attack, and its variations, may affect individual machines as well as entire 
networks.  Affected networks and/or systems will become bogged down with large amounts of network traffic, 
and users on affected systems may lose connectivity to the Internet.  The <b>Smurf</b> attack and its 
many variations have been known to last for a period of hours up to a day or more.

<h3>Resolutions</h3>

The key to protecting against, and suppressing these types of attacks, is to ensure that your 
network will not be used as an intermediary.  This may be done by configuring routers to not allow IP 
directed-broadcast transmissions (on Cisco routers, use the "no ip directed-broadcast" 
interface command).  All routers which provide routing to large multi-access broadcast networks, 
in other words LANs with more than 5 to 10 devices, should be configured in this way.  This resolution 
is indirect, but is, at this point, the surest method for eliminating these types of attacks.

<p>

Unfortunately, there is no sure method for protecting against being the ultimate target for <b>Smurf</b> 
type attacks.  For the <b>Smurf</b> attack, the surest and safest fix is to configure routers to turn away all incoming 
ICMP packets.  Unfortunately, this will render several ICMP dependent services, such as ping 
and traceroute, unusable.  Other router configuration methods do exist, and you may read about 
them in PSI's <A HREF = "http://www.support.psi.net/routers/smurfconfig.html">
Filter Configuration</a> page.  Other methods, such as ICMP filtering and dropping excess packets at 
network border routers, are not foolproof but may help alleviate the symptoms of <b>Smurf</b> type attacks.  
These methods are described in WinPlanet's 
<A HREF = "http://www.winplanet.com/features/reports/netexploits/index5.html">
Smurf Exploit</a> page, and also in  
<A HREF = "ftp://ds.internic.net/rfc/rfc2267.txt">InterNIC rfc2267</a>.  If you suspect that you have been the victim of a <b>Smurf</b> attack, you may 
want to download the <A HREF = "http://www.rootshell.com/archive-j457nxiqi3gq59dv/199807/smurflog-1.0.tgz.html">
Smurf Logger</a>, which will allow you to log future <b>Smurf</b> attacks (and other information, such 
as the broadcast address being used as the intermediary).

<p>

As with the <b>Smurf</b> attack, the <b>Fraggle</b> attack is particularly hard to defend against.  Some suggestions 
include blocking broadcast UDP at the router, and perhaps blocking UDP at all terminal servers 
as well (to prevent malicious network users from flooding out the network).  Read the <b>Smurf</b> 
information above for more information on router configuration tips and border router packet filtering 
techniques that may prove useful in defending against these types of attacks.

<h3><u>Where can I read more about this?</u></h3>

Visit Rootshell to read about the 
<A HREF = "http://www.rootshell.com/archive-j457nxiqi3gq59dv/199803/fraggle.c.html">
<b>Fraggle</b></a> and <A HREF = "http://www.rootshell.com/archive-j457nxiqi3gq59dv/199807/papasmurf.c.html">
<b>Papasmurf</b></a> Denial of Service attacks.

<p>

You can read more about the <b>Smurf</b> attack at Rootshell's 
<A HREF = "http://www.rootshell.com/archive-j457nxiqi3gq59dv/199710/smurf.c.html"><b>Smurf</b></a> page.  
Another good source of information is Craig A. Huegen's 
<A HREF = "http://www.quadrunner.com/~c-huegen/smurf.cgi">Smurf Whitepaper</a>.  
Be sure to also to read the <b>Smurf</b> information in 
<A HREF = "ftp://ftp.cert.org/pub/cert_advisories/CA-98.01.smurf">CERT Advisory 98.01</a>.  

	
<p>

To keep abreast of existing and emerging Denial of Service 
attacks, and other security threats, visit the  
<A HREF = "http://www.microsoft.com/security/">Microsoft Security Advisor</a>, the 
<A HREF = "http://www.windowscentral.com/features/reports/bugs/">
Windows Central Bug Site</a>, <A HREF = "http://www.cert.org">CERT</a>, and/or 
<A HREF = "http://www.irchelp.org">ircHelp</a>.  If information 
on a specific attack is not located on these sites, keep checking back as they 
are updated frequently.

</BODY>
<HR>
<A NAME="Possible_WUftpd_vulnerabilities">
<HTML>
<HEAD>
<TITLE>Tutorial - Possible WUftpd Vulnerabilities</TITLE>
</HEAD>
<BODY>

<H1>Possible WUftpd Vulnerabilities</H1>

<HR>

<H3>Summary</H3>

WUftpd:  A third party ftpd daemon that is popular in Linux distributions.
It is also found on many other platforms, installed by either the vendor or 
the user.  Several versions have been found vulnerable.  However, vendors
have patched this program but have not changed the version number (as 
displayed on the login banner).  Consequently, SARA can not confirm that
the program is vulnerable.

<H3>Impact</H3>

A remote intruder can execute commands as root if the buffer overflow
attack is successful (i.e, current target command is chdir).

<H3>The problem</H3>

The Washington University (WU) ftpd daemon is a powerful program that
adds many safeguards and configurable security options to the standard
ftpd distribution.  Unfortunately, it has been plagued with several 
vulnerabilites in the late 1990's.  The recent problem centers around
version wu-2.5.0(1).  the orginal version was vulnerable to the chdir attack.
Vendors, such as Red Hat, quickly fixed the problem but neglected to change
the version number.  As SARA assesses ftp vulnerability by version number,
it cannot determine if the new "version" has been applied.

<H3>Fix</H3>

<ul>

<li>Confirm that the system has the most up to date version of WUftpd.

<li>Otherwise, patch the system to a version that is not vulnerable to
the buffer overflow attack. However, there are reports that even patched 
versions may be vulnerable.

</ul>

<H3>Other tips</H3>

<ul>

CERT released <A HREF="http://www.cert.org/advisories/CA-99-13-wuftpd.html">
CA-99-13</A> advisory on this topic.

</ul>
</BODY>
</HTML>
<HR>
<A NAME="REXD_access">
<HTML>
<HEAD>
<TITLE>Tutorial - REXD access</TITLE>
</HEAD>
<BODY>

<H1>REXD access</H1>

<HR>

<H3>Summary</H3>

REXD remote access from arbitrary hosts.

<H3>Impact</H3>

A remote intruder can execute commands as any user.

<H3>Background</H3>

The <em>rexd</em> service and the <em>on</em> client program
implement remote command execution via the network.  To the extent that
it is possible, the complete client environment, including working
directory and environment variables, is made available on the remote
system.

<H3>The problem</H3>

A request for remote command execution contains, among others, the
command to be executed, and a user and group id.  By default, the rexd
server believes everything that the client sends it. An intruder can
exploit the service to execute commands as any user (except perhaps
<em>root</em>).  The typical rexd server has no protection against
abuse:  most implementations have no provision for access control, nor
do they require that the client uses a privileged network port.

<H3>Fix</H3>

<ul>

<li>Disable the rexd service. Usually this is accomplished by editing
the <em>inetd.conf</em> file, and by sending a HUP signal to the <em>
inetd</em> process.

<li>Some rexd implementations can be configured to use a more secure
protocol.  Consult your manual pages for details.

</ul>

<H3>Other tips</H3>

<ul>

<li>See the
<a href="http://www.clark.net/pub/arccom/stuff/admin_guide_to_cracking.html#rexd">Admin
Guide to Cracking</a> for an example of why this is a problem.

</ul>
</BODY>
</HTML>
<HR>
<A NAME="SMTP_may_be_a_mail_relay">

<HTML>
<HEAD>
<TITLE>Tutorial - Mail Relay Problem</TITLE>
</HEAD>
<BODY>

<H1>Mail Relay Problem </H1>

<H3>Impact</H3>

Older versions of the <B>sendmail</B> program did not provide sufficient 
safeguards against mailcious users sending spam mail through a third
party computer.  Further, the spam mail will often have a forged source
address.
<P>

<H3>Background</H3>

Until 1999, most implementations of <B>sendmail</B> and its clones provided 
little checking of source and destination addresses.  For example a user on 
host A could use the sendmail on Host B sending mail to a user on Host C
with a source email address from Host D.  In other words, A hacker on 
foo.bar.com would use the <B>sendmail</B> at host1.swip.se to send a message

<H3>Resolution</H3>

Vendor and Web server patches and workarounds to protect against this 
vulnerability are available.  If your vendor does not have an upgrade, 
current versions of sendmail from <A HREF="www.sendmail.org">sendmail.org</a>.
<p>
</BODY>
</HTML>
<HR>
<A NAME="SNMPD_available">
<HTML>
<HEAD>
<TITLE>Tutorial - Simple Network Management Protocol (SNMP) Access</TITLE>
</HEAD>
<BODY>

<H1>Simple Network Management Protocol
(SNMP) Access </H1>

<H3>Impact</H3>

SNMP provides useful information to the hacker on the characteristics
of the target host.  In addition, several vendors have poorly protected
"private" Management Information Blocks (MIBs) that can control the
target.
<P>
<H3>Resolution</H3>

Determine if your host requires SNMP.  On many systems it is installed
"out of the box".  Unless your enterprise uses SNMP for system management,
it may be prudent to simply "turn it off".  Check with your vendor on 
the easiest method for dectivating SNMP. 
<P>
If SNMP is required, check with your network management group to see if
if access can be limited to the enterprise.  Routers and firewalls 
provide this facility.
<P>
If SNMP must be available over the Internet, check with the
<A HREF="http://www.cert.org/advisories">CERT</A> to determine
if your configuration may be vulnerable.
</BODY>
</HTML>
<HR>
<A NAME="SSH-26_vulnerabilities">
<TITLE>SSH Vulnerabilities</TITLE>
<h1>SSH Agent Vulnerabilities</h1>

<h3> Impact</h3>
This document will detail a vulnerability in the <b><tt>ssh</tt></b> cryptographic
login program. The vulnerability enables users to use <a href="http://whatis.com/rsa.htm">RSA</a>
credentials belonging to other users who use the SSH-agent program. This
vulnerability may allow a malicious user/hacker on the same local host
to login to a remote server as the user utilizing <b><tt>ssh</tt></b>.
<h3>
<u>Background</u></h3>
<a href="http://www.ssh.fi/sshprotocols2/">Secure Shell</a>, or <b><tt>ssh</tt></b>,
is a program used to log into another computer over a network, execute
commands on a remote machine and move files from one machine to another.
It provides strong authentication and secure communications over unsecure
communication channels. <b><tt>ssh</tt></b> is intended as a replacement
for <b><tt><a href="http://www.jhu.edu/HAC/hcic/vmsman/subsection2_7_5_2.html">rlogin</a></tt></b>,
<b><tt><a href="http://nacphy.physics.orst.edu/coping-with-unix/node105.html">rsh</a></tt></b>
and <b><tt><a href="http://www.ncl.ac.uk/ucs/unix/rcp.html">rcp</a></tt></b>.
Additionally, <b><tt>ssh</tt></b> provides secure <b><tt><a href="http://www.tufts.edu/tccs/acs/help/X/">X</a></tt></b>
connections and secure forwarding of arbitrary <b><tt><a href="http://www.ce.net/users/super/tcpIp.intro.txt">TCP</a></tt></b>
connections. Traditional <a href="http://www.bsd.org/">BSD</a> "r" commands,
such as <b><tt>rsh</tt></b>, <b><tt>rlogin</tt></b> and <b><tt>rcp</tt></b>,
are vulnerable to a variety of different hacker attacks. A user with "<b><u>root</u></b>"
access to certain machines on the network, or physical access to the network
itself, may be able to gain unauthorized access to systems by exploiting
various vulnerabilities found in the BSD "r" commands. Also, it may be
possible for a malicious user to log all traffic to and from a target system,
including keystrokes and passwords. The <b><tt>X Window System</tt></b>
also has a number of vulnerabilities which may be exploited by hackers.
The use of <b><tt>ssh</tt></b> helps to correct these vulnerabilities.
Specifically, <b><tt>ssh</tt></b> protects against these attacks: <b><a href="http://www.zdwebopedia.com/TERM/I/IP_spoofing.html">IP
spoofing</a></b> (where the spoofer is on either a remote or local host),
<b><a href="http://www.telstra.com.au/pub/docs/security/800-10/node25.html">IP
source routing</a></b>, <b><a href="http://www.cs.princeton.edu/sip/news/sun-02-22-96.html">DNS
spoofing</a></b>, interception of cleartext passwords/data and attacks
based on listening to <b><tt>X</tt></b> authentication data and spoofed
connections to an <b><tt>X11</tt></b> server.
<h3>
<u>The Problem</u></h3>
The <b><tt>ssh</tt></b> package includes a program called the <b><tt>ssh-agent</tt></b>.
The <b><tt>ssh-agent</tt></b> manages the RSA keys for the <b><tt>ssh</tt></b>
program, and is used primarily to help users avoid having to type in their
pass phrase every time they wish to use <b><tt>ssh</tt></b>, <b><tt>slogin</tt></b>
or <b><tt>scp</tt></b>. When invoked, the <b><tt>ssh-agent</tt></b> program
creates a mode 700 directory in the <b>/tmp</b> directory, and then creates
an <b>AF_UNIX</b> socket in that directory. Later, the user will run a
program named <b><tt>ssh-add</tt></b>, which adds his or her provate key
to the set of keys managed by the <b><tt>ssh-agent</tt></b> program. When
a user wishes to utilize a program which requires RSA key authentication,
the <b><tt>ssh</tt></b> client connects to the <b>AF_UNIX</b> socket and
asks the <b><tt>ssh-agent</tt></b> program for the appropriate key.
<p>The vulnerability lies in the fact that when the <b><tt>ssh</tt></b>
client connects to the <b>AF_UNIX</b> socket, it is running as super-user,
or root, and performs insufficient permissions checking. This makes it
possible for users to trick their tt><b>ssh</b> clients into using credentials
belonging to other users. In other words, any users who utilize RSA authentication
and use the <b><tt>ssh-agent</tt></b> program may have their credentials
improperly used by a malicious user, who then may improperly access services
or programs on a host machine.
<p>This vulnerability effects the UNIX versions of <b><tt>ssh</tt></b>
only. Specifically, <b><tt>ssh</tt></b> for UNIX versions 1.2.17 through
1.2.21 are vulnerable if installed with default permissions. Versions of
<b><tt>ssh</tt></b> prior to 1.7.17 are subject to a different (but very
similar) attack. Additionally, the F-Secure <b><tt>ssh</tt></b> programs,
prior to version 1.3.3, are vulnerable to this attack. Version 1.1 of the
Windows-based <b><tt>ssh</tt></b> client, sold by Data Fellows, Inc. under
the F-Secure brand name, and versions 1.0/1.0a of the Macintosh <b><tt>ssh</tt></b>
client are not vulnerable to this attack. If you are unsure of which version
or brand of <b><tt>ssh</tt></b> you are running, type "<b>ssh -v</b>" at
the command prompt and that information will be given to you by the system.
If you are not sure if your version or brand of <b><tt>ssh</tt></b> is
vulnerable to this type of attack, please contact the appropriate vendor.
<h3>
<u>Resolutions</u></h3>
For those using the non-commercial versions of <b><tt>ssh</tt></b> for
UNIX, this vulnerability may be easily fixed. Simply upgrade to <a href="ftp://ftp.cs.hut.fi/pub/ssh">SSH
version 1.2.22</a> or later. For those using the F-Secure <b><tt>ssh</tt></b>
program, version 1.3.3 fixes this security problem. For those using the
Data Fellows <b><tt>ssh</tt></b> package, and who have a support contract,
the fix for this vulnerability is to upgrade to version 1.3.3, which may
be obtained from a local retailer. If you are using the Data Fellows <b><tt>ssh</tt></b>
package, but do not have a support contract, there is a <b>diff</b> file
which should fix this vulnerability. This <b>diff</b> file may be obtained
from the Data Fellows <a href="http://www.DataFellows.com/f-secure/support/ssh/bug/su132patch.html">SSH
Web site</a>.
<p>If the above fixes are not practical, or if administrators wish to use
a temporary fix until the above resolutions may be implemented, a workaround
to this problem is available. The temporary workaround is for administrators
to remove the setuid bit from the <b><tt>ssh</tt></b> binary. This will
prevent the attack from working, but will also disable a form of authentication
documented as rhosts-RSA. For example, if the <b><tt>ssh</tt></b> binary
is in the <b>/usr/local/bin</b> directory, the following command will remove
the setuid bit from the <b><tt>ssh</tt></b> binary: "<b><u>chmod u-s /usr/local/bin/ssh</u></b>".
<h3>
<u>Where can I read more about this?</u></h3>
This vulnerability is outlined in <a href="http://www.cert.org/advisories/CA-98.03.ssh-agent.html">Cert
Advisory 93.08</a>. For more information about the noncommercial UNIX versions
of <b><tt>ssh</tt></b>, be sure to visit SSH Communications Security's
<a href="http://www.cs.hut.fi/ssh">SSH Web site</a>. If you are using a
commercial version of <b><tt>ssh</tt></b> and need more information, please
visit <a href="http://www.DataFellows.com/f-secure">Data Fellows, Inc.</a>
</body>
</html>
<HR>
<A NAME="SSH_vulnerabilities">
<TITLE>SSH Vulnerabilities</TITLE>
<h1>SSH Agent Vulnerabilities</h1>

<h3> Impact</h3>
This document will detail a vulnerability in the <b><tt>ssh</tt></b> cryptographic
login program. The vulnerability enables users to use <a href="http://whatis.com/rsa.htm">RSA</a>
credentials belonging to other users who use the SSH-agent program. This
vulnerability may allow a malicious user/hacker on the same local host
to login to a remote server as the user utilizing <b><tt>ssh</tt></b>.
<h3>
<u>Background</u></h3>
<a href="http://www.ssh.fi/sshprotocols2/">Secure Shell</a>, or <b><tt>ssh</tt></b>,
is a program used to log into another computer over a network, execute
commands on a remote machine and move files from one machine to another.
It provides strong authentication and secure communications over unsecure
communication channels. <b><tt>ssh</tt></b> is intended as a replacement
for <b><tt><a href="http://www.jhu.edu/HAC/hcic/vmsman/subsection2_7_5_2.html">rlogin</a></tt></b>,
<b><tt><a href="http://nacphy.physics.orst.edu/coping-with-unix/node105.html">rsh</a></tt></b>
and <b><tt><a href="http://www.ncl.ac.uk/ucs/unix/rcp.html">rcp</a></tt></b>.
Additionally, <b><tt>ssh</tt></b> provides secure <b><tt><a href="http://www.tufts.edu/tccs/acs/help/X/">X</a></tt></b>
connections and secure forwarding of arbitrary <b><tt><a href="http://www.ce.net/users/super/tcpIp.intro.txt">TCP</a></tt></b>
connections. Traditional <a href="http://www.bsd.org/">BSD</a> "r" commands,
such as <b><tt>rsh</tt></b>, <b><tt>rlogin</tt></b> and <b><tt>rcp</tt></b>,
are vulnerable to a variety of different hacker attacks. A user with "<b><u>root</u></b>"
access to certain machines on the network, or physical access to the network
itself, may be able to gain unauthorized access to systems by exploiting
various vulnerabilities found in the BSD "r" commands. Also, it may be
possible for a malicious user to log all traffic to and from a target system,
including keystrokes and passwords. The <b><tt>X Window System</tt></b>
also has a number of vulnerabilities which may be exploited by hackers.
The use of <b><tt>ssh</tt></b> helps to correct these vulnerabilities.
Specifically, <b><tt>ssh</tt></b> protects against these attacks: <b><a href="http://www.zdwebopedia.com/TERM/I/IP_spoofing.html">IP
spoofing</a></b> (where the spoofer is on either a remote or local host),
<b><a href="http://www.telstra.com.au/pub/docs/security/800-10/node25.html">IP
source routing</a></b>, <b><a href="http://www.cs.princeton.edu/sip/news/sun-02-22-96.html">DNS
spoofing</a></b>, interception of cleartext passwords/data and attacks
based on listening to <b><tt>X</tt></b> authentication data and spoofed
connections to an <b><tt>X11</tt></b> server.
<h3>
<u>The Problem</u></h3>
The <b><tt>ssh</tt></b> package includes a program called the <b><tt>ssh-agent</tt></b>.
The <b><tt>ssh-agent</tt></b> manages the RSA keys for the <b><tt>ssh</tt></b>
program, and is used primarily to help users avoid having to type in their
pass phrase every time they wish to use <b><tt>ssh</tt></b>, <b><tt>slogin</tt></b>
or <b><tt>scp</tt></b>. When invoked, the <b><tt>ssh-agent</tt></b> program
creates a mode 700 directory in the <b>/tmp</b> directory, and then creates
an <b>AF_UNIX</b> socket in that directory. Later, the user will run a
program named <b><tt>ssh-add</tt></b>, which adds his or her provate key
to the set of keys managed by the <b><tt>ssh-agent</tt></b> program. When
a user wishes to utilize a program which requires RSA key authentication,
the <b><tt>ssh</tt></b> client connects to the <b>AF_UNIX</b> socket and
asks the <b><tt>ssh-agent</tt></b> program for the appropriate key.
<p>The vulnerability lies in the fact that when the <b><tt>ssh</tt></b>
client connects to the <b>AF_UNIX</b> socket, it is running as super-user,
or root, and performs insufficient permissions checking. This makes it
possible for users to trick their tt><b>ssh</b> clients into using credentials
belonging to other users. In other words, any users who utilize RSA authentication
and use the <b><tt>ssh-agent</tt></b> program may have their credentials
improperly used by a malicious user, who then may improperly access services
or programs on a host machine.
<p>This vulnerability effects the UNIX versions of <b><tt>ssh</tt></b>
only. Specifically, <b><tt>ssh</tt></b> for UNIX versions 1.2.17 through
1.2.21 are vulnerable if installed with default permissions. Versions of
<b><tt>ssh</tt></b> prior to 1.7.17 are subject to a different (but very
similar) attack. Additionally, the F-Secure <b><tt>ssh</tt></b> programs,
prior to version 1.3.3, are vulnerable to this attack. Version 1.1 of the
Windows-based <b><tt>ssh</tt></b> client, sold by Data Fellows, Inc. under
the F-Secure brand name, and versions 1.0/1.0a of the Macintosh <b><tt>ssh</tt></b>
client are not vulnerable to this attack. If you are unsure of which version
or brand of <b><tt>ssh</tt></b> you are running, type "<b>ssh -v</b>" at
the command prompt and that information will be given to you by the system.
If you are not sure if your version or brand of <b><tt>ssh</tt></b> is
vulnerable to this type of attack, please contact the appropriate vendor.
<h3>
<u>Resolutions</u></h3>
For those using the non-commercial versions of <b><tt>ssh</tt></b> for
UNIX, this vulnerability may be easily fixed. Simply upgrade to <a href="ftp://ftp.cs.hut.fi/pub/ssh">SSH
version 1.2.22</a> or later. For those using the F-Secure <b><tt>ssh</tt></b>
program, version 1.3.3 fixes this security problem. For those using the
Data Fellows <b><tt>ssh</tt></b> package, and who have a support contract,
the fix for this vulnerability is to upgrade to version 1.3.3, which may
be obtained from a local retailer. If you are using the Data Fellows <b><tt>ssh</tt></b>
package, but do not have a support contract, there is a <b>diff</b> file
which should fix this vulnerability. This <b>diff</b> file may be obtained
from the Data Fellows <a href="http://www.DataFellows.com/f-secure/support/ssh/bug/su132patch.html">SSH
Web site</a>.
<p>If the above fixes are not practical, or if administrators wish to use
a temporary fix until the above resolutions may be implemented, a workaround
to this problem is available. The temporary workaround is for administrators
to remove the setuid bit from the <b><tt>ssh</tt></b> binary. This will
prevent the attack from working, but will also disable a form of authentication
documented as rhosts-RSA. For example, if the <b><tt>ssh</tt></b> binary
is in the <b>/usr/local/bin</b> directory, the following command will remove
the setuid bit from the <b><tt>ssh</tt></b> binary: "<b><u>chmod u-s /usr/local/bin/ssh</u></b>".
<h3>
<u>Where can I read more about this?</u></h3>
This vulnerability is outlined in <a href="http://www.cert.org/advisories/CA-98.03.ssh-agent.html">Cert
Advisory 93.08</a>. For more information about the noncommercial UNIX versions
of <b><tt>ssh</tt></b>, be sure to visit SSH Communications Security's
<a href="http://www.cs.hut.fi/ssh">SSH Web site</a>. If you are using a
commercial version of <b><tt>ssh</tt></b> and need more information, please
visit <a href="http://www.DataFellows.com/f-secure">Data Fellows, Inc.</a>
</body>
</html>
<HR>
<A NAME="Sendmail_vulnerabilities">
<HTML>
<HEAD>
<TITLE>Tutorial - Sendmail vulnerabilities</TITLE>
</HEAD>
<BODY>

<H1>Sendmail vulnerabilities</H1>

<HR>

<H3>Summary</H3>

Assorted sendmail vulnerabilities.

<H3>The problems</H3>

With almost every sendmail version that was built before February 1998,
a malicious user can gain unauthorized privileges by exploiting
newlines in command-line arguments or in the process environment or in
buffer overflow attacks.  Intruders need to have access to an account on 
your system to exploit this problem.

<p>
<H3>Fix</H3>

<ul>

<li>Replace sendmail by a more recent version, for example from <a
href="http://www.sendmail.org">
www.sendmail.org</a>, or use a corrected version from
your vendor.

<li>Follow vendor instructions in the numerous advisories from
<A HREF="http://www.cert.org/advisories">CERT</A>
</ul>

<H3>Other tips</H3>

<ul>

<li>See the
<a href="http://www.clark.net/pub/arccom/stuff/admin_guide_to_cracking.html#sendmail">Admin
Guide to Cracking</a> for an example of why this is a problem.
 
</ul>
</BODY>
</HTML>
<HR>
<A NAME="TFTP_file_access">
<HTML>
<HEAD>
<TITLE>Tutorial - TFTP file access</TITLE>
</HEAD>
<BODY>

<H1>TFTP file access</H1>

<HR>

<H3>Summary</H3>

File access via the TFTP service.

<H3>Impact</H3>

Unauthorized remote access to system or user files.

<H3>Background</H3>

The TFTP (trivial file transfer protocol) service provides remote
access to files, without asking for a password. It is typically used
for the initialization of diskless computers, of X terminals, or of
other dedicated hardware.

<H3>The problem</H3>

When the TFTP daemon does not limit access to specific files or hosts,
a remote intruder can use the service to obtain copies of the password
file or of other system or user files, or to remotely overwrite files.

<H3>Fix</H3>

<ul>

<li>Restrict TFTP access to only limited subtree of the file system.
Consult your tftpd manual pages for details.

<li>When no access restriction is possible, restrict TFTP access by
using a tcp wrapper.

</ul>

<H3>Other tips</H3>

<ul>

<li>See the
<a href="http://www.clark.net/pub/arccom/stuff/admin_guide_to_cracking.html#tftp">Admin
Guide to Cracking</a> for an example of why this is a problem.

</ul>
</BODY>
</HTML>
<HR>
<A NAME="WUftpd_vulnerabilities">
<HTML>
<HEAD>
<TITLE>Tutorial - WUftpd Vulnerabilities</TITLE>
</HEAD>
<BODY>

<H1>Washington University FTP Vulnerabilities</H1>

<H3>Impact</H3>
<P>
Any server running the versions prior to December 1998 of ProFTPD 
(1.2.0pre1) or of Wuarchive ftpd (2.4.2-academ[BETA-18]).  wu-ftpd is
installed and enabled by default on most Linux variants such as RedHat
and Slackware Linux.  ProFTPD is new software recently adopted by many
<P>
<H3>Background</H3>
<P>
There is a general class of vulnerability that exists in several
popular ftp servers.  Due to insufficient bounds checking, it is
possible to subvert an ftp server by corrupting its internal stack
space.  By supplying carefully designed commands to the ftp server,
intruders can force the the server to execute arbitrary commands with
root privilege.

On most vulnerable systems, the ftpd software is installed and enabled
by default.
<P>
<H3>Resolution</H3>
<P>

Currently there are several ways to exploit the ftp servers in
question.  One temporary workaround against an anonymous attack is to
disable any world writable directories the user may have access to by
making them read only.  This will prevent an attacker from building an
unusually large path, which is required in order to execute these
particular attacks.

The permanent solution is to install a patch from your Vendor, or
locate one provided by the Software's author or maintainer.  See
Appendices A and B for more specific information.
<p>

<H3>Where can I read more about this?</H3>

You may read more about this vulnerability in <A HREF="http://www.cert.org/advisories/CA-99-03-FTP-Buffer-Overflows.html">
CERT Advisory 99.03</a>.  
</BODY>
</HTML>
<HR>
<A NAME="automounter_version">
<HTML>
<HEAD>
<TITLE>Tutorial - Automounter Version</TITLE>
</HEAD>
<BODY>

<H1>Automounter Version</H1>

<HR>

<H3>Summary</H3>

amd: This daemon automatically mounts file systems in response to 
attempts to access files that reside on those file systems. Similar 
functionality on some systems is provided by a daemon named automountd.
Linux and BSD oriented systems are especially vulnerable.


<H3>Impact</H3>

A remote intruder can execute commands as root if the buffer overflow
attack is successful.

<H3>The problem</H3>

The amd (or automountd) daemon is exploitable for remote root access.  
Versions are vulnerable to a buffer overflow attack where a well crafted 
pattern could execute arbitrary commands as the root user. 

<H3>Fix</H3>

<ul>

<li>Where possible, disable amd (or automountd) in <em>inetd.conf</em> file
or the appropriate <em>init.d</em> file.

<li>Otherwise, patch the system to a version that is not vulnerable to
the buffer overflow attack.  

</ul>

<H3>Other tips</H3>

<ul>

CERT released <A HREF="http://www.cert.org/advisories/CA-99-12-amd.html">
CA-99-12</A> advisory on this topic.

</ul>
</BODY>
</HTML>
<HR>
<A NAME="backdoor_found">
<HEAD>
<TITLE>Tutorial - Windows "Backdoor" Vulnerability</TITLE>
</HEAD>
<BODY>

<H1>Windows "Backdoor" Vulnerability</H1>
<P>
<HR>
<P>
<H3>Summary</H3>

Several "trojan horses" have been introduced to the Microsoft Windows
environment including Back Oriffice, Netbus, and Netbus II.

<H3>Impact</H3>

These "Trojans" allow a malicious user to manipulate a Microsoft Windows
system without the knowledge of the legitimate user.

<H3>Problem</H3>

Back Oriffice, Netbus, and Netbus II are "Trojan Horse" programs that resemble
computer viruses in that they are inadevertantly installed by the user.  
Once installed, their presence is difficult to detect.  These "backdoors"
allow the hacker to manipulate the compromised host at will.  Data can be
compromised or modified.

<H3>Resolution</H3>
<P>
SARA detects possible signtures of "backdoor" pressence.  It is up to 
you, the user to confirm that the "backdoors" are really present.  Refer
to the 
<A HREF="http://www.microsoft.com">Microsoft Site</A> fro details in
confirming the presence of the "backdoors.
</BODY>
</HTML>
<HR>
<A NAME="distributed_denial_of_service">
<HTML>
<HEAD>
<TITLE>Tutorial - Distributed Denial-of-Service Tools</TITLE>
<!-- From SAINT 1.5.Beta -->
</HEAD>
<BODY>

<H2>Distributed Denial-of-Service Tools</H2>

<H3><u>Impact</u></H3>

The presence of a distributed denial-of-service tool is a powerful threat to the
entire network. It could also be used to attack other networks, and the owner of the infected
network could be held responsible. The presence of a distributed denial-of-service
tool is also an indication that the system has already been compromised.

<H3><u>Background</u></H3>

Distributed denial-of-service is a type of attack in which a large number
of hosts are used to flood a single target with unwanted traffic.  The target
becomes unusable while it is processing the flood of traffic. An attacker
who breaks into many hosts on a network and sets up such a distributed
denial-of-service attack can create a threat that is very powerful and
difficult to defend against.

<H3><u>The Problem</u></H3>

<b>Trinoo</b> is one such distributed denial-of-service tool. A trinoo network
consists of a <b>master</b> host and many <b>broadcast</b> hosts. When an
attacker wishes to launch a denial-of-service attack, he or she issues
commands to the master host using a TCP connection.  The master then communicates with all of
the broadcast hosts via UDP, telling them to send a flood of UDP packets
to random ports on the specified target host. The flood of UDP packets coming
from the broadcast hosts causes denial of service to the target
host.  An attacker must have prior access
to a host in order to install a trinoo master or broadcast, either by breaking
in or by some other means.
<p>
Tribe Flood Network (<b>TFN</b>) is another distributed denial-of-service tool,
consisting of a <b>client</b> host and many <b>daemon</b> hosts.
It is similar to trinoo, but communicates using ICMP, and is capable of
launching ICMP flood, UDP flood,
<A HREF="http://www.zdnet.com/pcmag/pctech/content/17/08/nt1708.003.html">
SYN flood</A>, and
<A HREF="http://www.zdnet.com/pcmag/pctech/content/17/08/nt1708.004.html">
Smurf</A> attacks. A newer version of TFN called <b>TFN2K</b> includes
many additional features, such as encryption, stealth attacks, denial-of-service
attacks designed to crash the target host, and the ability to send
shell commands to the daemons.
<p>
<b>Stacheldraht</b> is a similar tool which consists of a <b>handler</b> and
many <b>agents</b>. It communicates using TCP and ICMP, offers the same
attacks as TFN, and features encrypted sessions between the attacker and
the handlers.

<h3><u>Resolution</u></h3>

Although a distributed denial-of-service tool can be easily eradicated from a
single system, its presence is an indication of a much bigger problem.
The fact that it was installed on one system makes
it likely to be installed on many more systems. The entire network should
be scanned.
Furthermore, the presence of the tool means that the system was probably compromised.
Trinoo, TFN, and stacheldraht are often associated with breakins resulting from vulnerabilities
in <A HREF="tooltalk_version.html">Tooltalk</A>, <A HREF="rpc_cmsd_version.html">
Calendar Manager</A>, <A HREF="http://www.cert.org/advisories/CA-99-12-amd.html">
<tt>amd</tt></A>, <A HREF="rpc_statd_access.html"><tt>statd</tt></A>, 
<A HREF="sadmind_version.html">sadmind</a> and
<A HREF="http://www.cert.org/advisories/CA-98.12.mountd.html"><tt>mountd</tt></A>,
but could have been put on the system no matter how the compromise occurred.
An infected system should be taken off the network until all vulnerabilities
have been corrected and the system has been inspected for other backdoors and
hacker trails.
<P>
To eradicate trinoo, TFN, or stacheldraht from a single system,
kill the process and delete the executable file from the system. The
processes have the following names by default, but the intruder could
easily have chosen a different name, or could even have hidden the
files and processes using a <i>rootkit</i>.
<p>
<DL>
<DT><B>Trinoo</B>
<DD>Master: <tt>master</tt>
<DD>Broadcast: <tt>ns</tt>
<P>
<DT><B>TFN</B>
<DD>Client: <tt>tfn</tt>
<DD>Daemon: <tt>td</tt>
<P>
<DT><B>Stacheldraht</B>
<DD>Handler: <tt>mserv</tt>
<DD>Agent: <tt>td</tt>
</DL>

<H3><u>Where can I read more about this?</u></H3>

More information about trinoo and TFN can be found in the
<A HREF="http://xforce.iss.net/alerts/advise40.php3">X-Force
Alert</A> and in <A HREF="http://www.cert.org/incident_notes/IN-99-07.html">
CERT Incident Note 99-07</A>.  Developments in the area
of distributed denial-of-service tools are reported in
CERT Advisories
<A HREF="http://www.cert.org/advisories/CA-99-17-denial-of-service-tools.html">
99-17</A> and <A HREF="http://www.cert.org/advisories/CA-2000-01.html">
2000-01</A>. For detailed technical information, see David Dittrich's
papers on
<A HREF="http://staff.washington.edu/dittrich/misc/trinoo.analysis">trinoo</A>,
<A HREF="http://staff.washington.edu/dittrich/misc/tfn.analysis">TFN</A>, and
<A HREF="http://staff.washington.edu/dittrich/misc/stacheldraht.analysis">stacheldraht</A>,
<P>
This tutorial was derived from SAINT 1.5.
</BODY>
</HTML>
<HR>
<A NAME="excessive_finger_info">
<HEAD>
<TITLE>Tutorial - Excessive Finger Information</TITLE>
</HEAD>
<BODY>

<H1>Excessive Finger Information</H1>

<H3>Summary</H3>

Certain finger servers, when queried, will release excess data about accounts
on the system including who is currently logged on.

<H3>Impact</H3>

This excess information could be used as clues for guessing user passwords,
determining when the system is idle, and providing indicators when to best
attack the system.

Many finger servers provide excessive information on users of the system.
It may provide a list of users and associated personal information.  It
also indicates who is logged on.  This information can provide the
hacker with valuable data to (1) guess poor passwords and (2) determine the
optimum time to hack.

<H3>Resolution</H3>

There are several methods of limiting finger information. If you don't use
finger by disabling it in inetd.conf (then restart the inet daemon).  
If you need finger for your enterprise, you can install tcp wrappers and 
limit access.  
</BODY>
</HTML>
<HR>
<A NAME="hacker_program_found">
<HTML>
<HEAD>
<TITLE>Tutorial - Hacker Program Found</TITLE>
</HEAD>
<BODY>

<H1>Hacker Program Found</H1>

<H3>Impact</H3>

This advisory indicates that a hacker program has been detected on the scanned host.  This
advisory will only be generated when SARA is in the <i>extreme</i> attack mode.

<H3><u>Background</u></H3>

This warning refers to a hacker program called <tt><b>BNC</b></tt>, which is a simple 
program designed to proxy IRC sessions.  It is user configurable 
using the file <em>bnc.conf</em> to set incoming and outgooing ports, user ID, and
password.  Hackers use this program to prove to their community that they have hacked
into the target computer. 

<H3><u>The Problem</u></H3>

This warning does not point out a vulnerability in and of itself.  But, it 
does indicate that the target system may have been compromised, and that a 
vulnerability may exist on the system.  In order to run the <tt><b>bnc</b></tt> 
program, a hacker must have interactive access to the target system.

<H3><u>Resolution</u></H3>

The first step is to kill the <tt><b>BNC</b></tt> program.  The next step is 
to search the system for evidence of a hacker's presence.  After determining that 
a hacker is not currently accessing the system, run a full check of the system 
to determine how the hacker gained access and eliminate any existing vulnerabilities.

</BODY>
</HTML>
<HR>
<A NAME="http_cgi_access">
<HTML>
<HEAD>
<TITLE>Tutorial - Common Gateway Interface (CGI) Access</TITLE>
</HEAD>
<BODY>

<H1>Common Gateway Interface Interface 
(CGI) Access</H1>

<H3>Impact</H3>

Older Web server implementations contained CGI scripts that would allow 
the user to access files and execute commands on the server.  However, 
these scripts did not adequately address security and are exploited to 
(1) download system and user files, (2) execute commands as the Web 
administrator and (3) contaminate Web pages.
<P>
Several problems with Microsoft Internet Information Servers (IIS) are
also addressed here.  Many FrontPage installations allow the malicious
user to read, delete, and modify pages on an IIS (and other FrontPage 
supported) sites.  Also, many IIS distributions have sample programs
enabled that enable the hacker to read, delete, or modify web pages.
<P>
A recent (1999) exploit in ColdFusion extensions could enable the malicious
user to alter web pages.

<H3>Background</H3>

Security vulnerabilities have been reported in numerous CGI scripts, including 
webdist.cgi, handler.cgi, phf, htmlscript, view-source, and
php.cgi.  These scripts can provide the malicious user access to data and 
programs on the Web server host. 
<P>
Similar vulnerabilities may be present with IIS servers (codebrws and 
FrontPage) as well as third part add-ons such as ColdFusion. In addition, 
Microsoft's RDS facility is often exploited through IIS.

<H3>Resolution</H3>

Vendor and Web server patches and workarounds to protect against this 
vulnerability are available from Silicon Graphics Inc., the Apache Group,  
NCSA, Microsoft, and Allaire (ColdFusion) and should be applied as soon as 
possible.  A workaround to this problem is to remove the execute permissions 
on the offending scripts to prevent their exploitation.  If the scripts are 
not required, they should be removed from the system.
<p>
<H3>Where can I read more about this?</H3>

You may read more about this vulnerability in 
<A HREF="http://www.cert.org/advisories/CA-97.12.webdist.html">
CERT Advisory 97.12</a>.  For those interested in reading more about 
general WWW security and secure CGI programming, visit the 
<A HREF="http://www-genome.wi.mit.edu/WWW/faqs/www-security-faq.html">
World Wide Web Security FAQ</a>.
<P>
For a description of the IIS and ColdFusion exploits, go to
<A HREF="http://www.phrack.com">Phrack Magazine</A>. Information on
Frontpage can be found at 
<A HREF="http://support.microsoft.com/support/frontpage/Q152306/default.asp">
Microsoft</A> and information on RDS can be found at
<A HREF="http://www.attrition.org/security/advisory/rfp/rfp.9907.msadcs">
RDS</A>.
</BODY>
</HTML>
<HR>
<A NAME="imap_version">
<HTML>
<HEAD>
<TITLE>Tutorial - Vulnerable IMAP and POP Versions</TITLE>
</HEAD>
<BODY>

<H1>Vulnerable IMAP and POP Versions</H1>

<H3>Impact</H3>

Remote users may root access on systems running a vulnerable <tt><b>IMAP</b></tt> or 
<tt><b>POP</b></tt> that is vulnerable to buffer overflow attacks.
Access to an account on the system is not needed to exploit this vulnerability. 

<H3>Background</H3>

<tt><b>IMAP</b></tt>  provides remote access to a user's mailbox.  It maintains a list
of unread as well as read messages so that a user gets the same "view" in a multiple 
mail client environment.
<p>
<tt><b>POP</b></tt>is similar to <tt><b>IMAP</b></tt> but all received mail is loaded 
to the mail client.  That is, the client connects to the server to download mail that 
the server is holding for the client. The mail is deleted from the server and is handled 
offline (locally) on the client machine.

<H3>The Problem</H3>

This vulnerability allows remote intruders to execute arbitrary commands under the 
privleges of the process running the vulnerable IMAP server. If the 
vulnerable IMAP server is running as root, remote intruders can gain root access.
<H3><u>Resolution</u></H3>

Install a patch from your vendor or upgrade to the 
<A HREF = "ftp://ftp.cac.washington.edu/mail/imap.tar.Z">latest version 
of <tt><b>IMAP</b></tt></a>. If your <tt><b>POP</b></tt> server is based on the University 
of Washington <tt><b>IMAP</b></tt> server code, you should also upgrade to the 
<A HREF = "ftp://ftp.cac.washington.edu/mail/imap.tar.Z">latest 
version of <tt><b>IMAP</b></tt></a>.

<p>

Until you can take one of the above actions, temporarily disable the <tt><b>POP</b></tt> 
and <tt><b>IMAP</b></tt> services. On many systems, you will need to edit the 
<tt>/etc/<em>inetd.conf</em></tt> file. However, you should check your vendor's 
documentation because systems vary in file location and the exact changes required 
(for example, sending the <tt><b>inetd</b></tt> process a HUP signal or killing and 
restarting the daemon).  


<H3>Where can I read more about this?</H3>

Read more about this vulnerability in <A HREF = "http://www.cert.org/advisories/CA-97.09.imap_pop.html">
CERT Advisory 97.09</a>, 
<A HREF="http://www.cert.org/CA-98.08.qpopper_vul.html">CERT Advisory 98.08</a>, and
<A HREF="http://www.cert.org/CA-98.09.imapd.html">CERT Advisory 98.09</a>.

</BODY>
</HTML>
<HR>
<A NAME="mountd_vulnerabilities">
<TITLE>Mountd Vulnerabilities</TITLE>
<H1>Mountd Exploit</H1>
<P>
<H3> Overview:</H3>

NFS is a distributed file system in which clients make use of file
systems provided by servers. There is a vulnerability in some
implementations of the software that NFS servers use to log requests
to use file systems.

<P>When a client makes a request to use a file system and subsequently
makes that file system available as a local resource, the client is
said to "mount" the file system. The vulnerability lies in the
software on the NFS server that handles requests to mount file
systems. This software is usually called "mountd" or "rpc.mountd."

<P>Intruders who exploit the vulnerability are able to gain
administrative access to the vulnerable NFS file server. That is, they
can do anything the system administrator can do. This vulnerability
can be exploited remotely and does not require an account on the
target machine.

<P>On some vulnerable systems, the mountd software is installed and
enabled by default. 

<H2>Description</H2>
NFS is used to share files among different computers over the network
using a client/server paradigm. When an NFS client computer wishes to
access files on an NFS server, the client must first make a request to
mount the file system. There is a vulnerability in some
implementations of the software that handles NFS mount requests (the
mountd program). Specifically, it is possible for an intruder to
overflow a buffer in the area of code responsible for logging NFS
activity.

<P>We have received reports indicating that intruders are actively
using this vulnerability to compromise systems and are engaging in
large-scale scans to locate vulnerable systems.

<P>On some systems, the vulnerable NFS server is enabled by
default. 

<H2>Impact</H2>

After causing a buffer overflow, a remote intruder can use the
resulting condition to execute arbitrary code with root privileges.

<H2>Solution</H2>

Install a vendor patch.
<P>
Consider disabling NFS until you are able to install the
patch. In particular, since some systems have vulnerable versions of
mountd installed and enabled by default, we recommend you disable
mountd on those systems unless you are actively using those systems as
NFS servers.&nbsp; 
<HR>
<A NAME="netbios_over_the_internet">
<HTML>
<HEAD>
<TITLE>Tutorial - NetBIOS Over the Internet</TITLE>
</HEAD>
<BODY>

<H1>NetBIOS over the Internet</H1>

<H3>Impact</H3>

NETBIOS services were detected by the SARA scan.  However, the SAMBA module was not
loaded and an active scan of the SMB shares was not possible.  This advisory is
applicable to both UNIX and Microsoft Windows products.

<H3><u>The Problem</u></H3>

No actual vulnerability was detected because SARA could not find SAMBA resources. 

<H3><u>Resolution</u></H3>

Where possible, NETBIOS services should be disabled.  Where this is not possible, the 
system administrator should confirm that there are no open SMB shares.
</BODY>
</HTML>
<HR>
<A NAME="open_SMB_shares">
<HTML>
<HEAD>
<TITLE>Tutorial - Unrestricted SMB Access</TITLE>
</HEAD>
<BODY>

<H1>Unrestricted SMB Access</H1>

<HR>

<H3>Summary</H3>

Server Message Block (SMB) files shares are world accessable.  SARA
could access an SMB share.  SARA could do a directory listing of the
indicated share.  No attempt was made to read or write to the contents
of the directories.

<H3>Impact</H3>


<H3>The Problem</H3>

This vulnerability allows hackers to access files that have been "shared"
to the world without the need of a password or special account.

<H3>Fix</H3>

Confirm that there are no open shares that allow universal access.  This
is true for Microsoft Windows and Unix operating SAMBA.
</BODY>
</HTML>
<HR>
<A NAME="pop3_version">
<HTML>
<HEAD>
<TITLE>Tutorial - Vulnerable IMAP and POP Versions</TITLE>
</HEAD>
<BODY>

<H1>Vulnerable IMAP and POP Versions</H1>

<H3>Impact</H3>

Remote users may root access on systems running a vulnerable <tt><b>IMAP</b></tt> or 
<tt><b>POP</b></tt> that is vulnerable to buffer overflow attacks.
Access to an account on the system is not needed to exploit this vulnerability. 

<H3>Background</H3>

<tt><b>IMAP</b></tt>  provides remote access to a user's mailbox.  It maintains a list
of unread as well as read messages so that a user gets the same "view" in a multiple 
mail client environment.
<p>
<tt><b>POP</b></tt>is similar to <tt><b>IMAP</b></tt> but all received mail is loaded 
to the mail client.  That is, the client connects to the server to download mail that 
the server is holding for the client. The mail is deleted from the server and is handled 
offline (locally) on the client machine.

<H3>The Problem</H3>

This vulnerability allows remote intruders to execute arbitrary commands under the 
privleges of the process running the vulnerable IMAP server. If the 
vulnerable IMAP server is running as root, remote intruders can gain root access.
<H3><u>Resolution</u></H3>

Install a patch from your vendor or upgrade to the 
<A HREF = "ftp://ftp.cac.washington.edu/mail/imap.tar.Z">latest version 
of <tt><b>IMAP</b></tt></a>. If your <tt><b>POP</b></tt> server is based on the University 
of Washington <tt><b>IMAP</b></tt> server code, you should also upgrade to the 
<A HREF = "ftp://ftp.cac.washington.edu/mail/imap.tar.Z">latest 
version of <tt><b>IMAP</b></tt></a>.

<p>

Until you can take one of the above actions, temporarily disable the <tt><b>POP</b></tt> 
and <tt><b>IMAP</b></tt> services. On many systems, you will need to edit the 
<tt>/etc/<em>inetd.conf</em></tt> file. However, you should check your vendor's 
documentation because systems vary in file location and the exact changes required 
(for example, sending the <tt><b>inetd</b></tt> process a HUP signal or killing and 
restarting the daemon).  


<H3>Where can I read more about this?</H3>

Read more about this vulnerability in <A HREF = "http://www.cert.org/advisories/CA-97.09.imap_pop.html">
CERT Advisory 97.09</a>, 
<A HREF="http://www.cert.org/CA-98.08.qpopper_vul.html">CERT Advisory 98.08</a>, and
<A HREF="http://www.cert.org/CA-98.09.imapd.html">CERT Advisory 98.09</a>.

</BODY>
</HTML>
<HR>
<A NAME="possible_http_cgi_access">
<HTML>
<HEAD>
<TITLE>Tutorial - Possible Common Gateway Interface (CGI) Access</TITLE>
</HEAD>
<BODY>

<H1>Possible Common Gateway Interface 
(CGI) Access</H1>

<H3>Impact</H3>

<b>Note:</b> Vulnerabilities described here are less serious than those
described in <A HREF="./http_cgi_access.html">Common Gateway Interface Access</a>
as (1) the data compromise is more limited or (2) SARA could not confirm
the vulnerability.
<P>
Older Web server implementations contained CGI scripts that would allow 
the user to access files and execute commands on the server.  However, 
these scripts did not adequately address security and are exploited to 
(1) download system and user files, (2) execute commands as the Web 
administrator and (3) contaminate Web pages.
<P>
Several problems with Microsoft Internet Information Servers (IIS) are
also addressed here.  Many FrontPage installations allow the malicious
user to read, delete, and modify pages on an IIS (and other FrontPage 
supported) sites.  Also, many IIS distributions have sample programs
enabled that enable the hacker to read, delete, or modify web pages.
<P>
A recent (1999) exploit in ColdFusion extensions could enable the malicious
user to alter web pages.

<H3>Background</H3>

Security vulnerabilities have been reported in numerous CGI scripts, including 
webdist.cgi, handler.cgi, phf, htmlscript, view-source, and
php.cgi.  These scripts can provide the malicious user access to data and 
programs on the Web server host. 
<P>
Similar vulnerabilities may be present with IIS servers (codebrws and 
FrontPage) as well as third part add-ons such as ColdFusion.

<H3>Resolution</H3>

Vendor and Web server patches and workarounds to protect against this 
vulnerability are available from Silicon Graphics Inc., the Apache Group,  
NCSA, Microsoft, and Allaire (ColdFusion) and should be applied as soon as 
possible.  A workaround to this problem is to remove the execute permissions 
on the offending scripts to prevent their exploitation.  If the scripts are 
not required, they should be removed from the system.
<p>
<H3>Where can I read more about this?</H3>

You may read more about this vulnerability in 
<A HREF="http://www.cert.org/advisories/CA-97.12.webdist.html">
CERT Advisory 97.12</a>.  For those interested in reading more about 
general WWW security and secure CGI programming, visit the 
<A HREF="http://www-genome.wi.mit.edu/WWW/faqs/www-security-faq.html">
World Wide Web Security FAQ</a>.
<P>
For a description of the IIS and ColdFusion exploits, go to
<A HREF="http://www.phrack.com">Phrack Magazine</A>.
</BODY>
</HTML>
<HR>
<A NAME="possible_pop3_version">
<HTML>
<HEAD>
<TITLE>Tutorial - Possible Vulnerable IMAP and POP Versions</TITLE>
</HEAD>
<BODY>

<H1>Possible Vulnerable IMAP and POP 
Versions</H1>

<H3>Impact</H3>

<b>Note:</b> Vulnerabilities described here cannot be confirmed as 
described in <A HREF="./pop3_version.html">Vulnerable IMAP and POP 
Versions</a> as (1) the data compromise is more limited or (2) SARA could 
not confirm the vulnerability.
<P> 
Remote users could obtain root access on systems running a vulnerable <tt><b>
IMAP</b></tt> or <tt><b>POP</b></tt> that is vulnerable to buffer overflow 
attacks.
Access to an account on the system is not needed to exploit this vulnerability. 

<H3>Background</H3>

<tt><b>IMAP</b></tt>  provides remote access to a user's mailbox.  It maintains a list
of unread as well as read messages so that a user gets the same "view" in a multiple 
mail client environment.
<p>
<tt><b>POP</b></tt>is similar to <tt><b>IMAP</b></tt> but all received mail is loaded 
to the mail client.  That is, the client connects to the server to download mail that 
the server is holding for the client. The mail is deleted from the server and is handled 
offline (locally) on the client machine.

<H3>The Problem</H3>

This vulnerability allows remote intruders to execute arbitrary commands under the 
privleges of the process running the vulnerable IMAP server. If the 
vulnerable IMAP server is running as root, remote intruders can gain root access.
<H3><u>Resolution</u></H3>

If applicable, install a patch from your vendor or upgrade to the 
<A HREF = "ftp://ftp.cac.washington.edu/mail/imap.tar.Z">latest version 
of <tt><b>IMAP</b></tt></a>. If your <tt><b>POP</b></tt> server is based on the University 
of Washington <tt><b>IMAP</b></tt> server code, you should also upgrade to the 
<A HREF = "ftp://ftp.cac.washington.edu/mail/imap.tar.Z">latest 
version of <tt><b>IMAP</b></tt></a>.

<p>

Until you can take one of the above actions, temporarily disable the <tt><b>POP</b></tt> 
and <tt><b>IMAP</b></tt> services. On many systems, you will need to edit the 
<tt>/etc/<em>inetd.conf</em></tt> file. However, you should check your vendor's 
documentation because systems vary in file location and the exact changes required 
(for example, sending the <tt><b>inetd</b></tt> process a HUP signal or killing and 
restarting the daemon).  


<H3>Where can I read more about this?</H3>

Read more about this vulnerability in <A HREF = "http://www.cert.org/advisories/CA-97.09.imap_pop.html">
CERT Advisory 97.09</a>, 
<A HREF="http://www.cert.org/CA-98.08.qpopper_vul.html">CERT Advisory 98.08</a>, and
<A HREF="http://www.cert.org/CA-98.09.imapd.html">CERT Advisory 98.09</a>.

</BODY>
</HTML>
<HR>
<A NAME="relaying_possible_through_ftp_bounce">

<HTML>
<HEAD>
<TITLE>Tutorial - FTP Bounce Problem</TITLE>
</HEAD>
<BODY>

<H1>FTP Relay Problem </H1>

<H3>Impact</H3>

Under Construction.
<P>

<H3>Background</H3>

Under Construction.

<H3>Resolution</H3>

Under Construction.
<p>
</BODY>
</HTML>
<HR>
<A NAME="remote_shell_access">
<HTML>
<HEAD>
<TITLE>Tutorial - remote shell access</TITLE>
</HEAD>
<BODY>

<H1>Remote shell access</H1>

<HR>

<H3>Summary</H3>

Remote shell/remote login access from arbitrary hosts.

<H3>Impact</H3>

The machine can be taken over by any malicious (super)user on the network.

<H3>The problem</H3>

When the remote login/remote shell service trusts every host on the
network,  a malicious superuser on an arbitrary host can gain access as
any user (except perhaps <em>root</em>).  Once inside, the intruder
can replace system programs or configuration files (such as the
password file) and take over the machine.

<p>
In addition, there are guest or administrative accounts that might not
have passwords protecting the account, which allows anyone to remotely
login as that user and gain access to the host.

<H3>Fix</H3>

Remove the wildcard (+) from the /etc/hosts.equiv file. Be careful with
incorrect implementations.

<p>

Delete or disable any accounts without a password from the system or
NIS password file.

<H3>Other tips</H3>

<ul>

<li> Give system accounts such as <em>bin</em> and <em> daemon</em> a
non-functional shell (such as <em>/bin/false</em>) and put them in
the <em>/etc/ftpusers</em> file so they cannot use ftp.

<li>See the
<a href="http://www.clark.net/pub/arccom/stuff/admin_guide_to_cracking.html#remote-shell-access">Admin
Guide to Cracking</a> for an example of why this is a problem.

</ul>
</BODY>
</HTML>
<HR>
<A NAME="remote_shell_on_the_internet">
<HTML>
<HEAD>
<TITLE>Tutorial - remote shell on the Internet</TITLE>
</HEAD>
<BODY>

<H1>Remote shell on the Internet</H1>

<HR>

<H3>Summary</H3>

Remote shell/remote login access may be possible.

<H3>Impact</H3>

The machine advertises rsh or rlogin as available services. SARA cannot
determine if there are vulnerable accounts that can be accessed.

<H3>The problem</H3>

When the remote login/remote shell service trusts other hosts/and or
users on the
network,  a malicious user could possibly gain access.  However, SARA
cannot verify that any vulnerability exists. 

<H3>Fix</H3>

Review any <tt>.hosts</tt> or the <tt>/etc/hosts.equiv</tt> files do not
have excessive permissions.  Excessive permissions may include the "+"
character.
<p>
Delete or disable any accounts without a password from the system or
NIS password file.

<H3>Other tips</H3>

<ul>

<li> Give system accounts such as <em>bin</em> and <em> daemon</em> a
non-functional shell (such as <em>/bin/false</em>) and put them in
the <em>/etc/ftpusers</em> file so they cannot use ftp.

<li>See the
<a href="http://www.clark.net/pub/arccom/stuff/admin_guide_to_cracking.html#remote-shell-access">Admin
Guide to Cracking</a> for an example of why this is a problem.

</ul>
</BODY>
</HTML>
<HR>
<A NAME="rexec_on_the_Internet">
<HTML>
<HEAD>
<TITLE>Tutorial - remote shell access</TITLE>
</HEAD>
<BODY>

<H1>Remote shell access</H1>

<HR>

<H3>Summary</H3>

Remote shell/remote login access from arbitrary hosts.

<H3>Impact</H3>

The machine can be taken over by any malicious (super)user on the network.

<H3>The problem</H3>

When the remote login/remote shell service trusts every host on the
network,  a malicious superuser on an arbitrary host can gain access as
any user (except perhaps <em>root</em>).  Once inside, the intruder
can replace system programs or configuration files (such as the
password file) and take over the machine.

<p>
In addition, there are guest or administrative accounts that might not
have passwords protecting the account, which allows anyone to remotely
login as that user and gain access to the host.

<H3>Fix</H3>

Remove the wildcard (+) from the /etc/hosts.equiv file. Be careful with
incorrect implementations.

<p>

Delete or disable any accounts without a password from the system or
NIS password file.

<H3>Other tips</H3>

<ul>

<li> Give system accounts such as <em>bin</em> and <em> daemon</em> a
non-functional shell (such as <em>/bin/false</em>) and put them in
the <em>/etc/ftpusers</em> file so they cannot use ftp.

<li>See the
<a href="http://www.clark.net/pub/arccom/stuff/admin_guide_to_cracking.html#remote-shell-access">Admin
Guide to Cracking</a> for an example of why this is a problem.

</ul>
</BODY>
</HTML>
<HR>
<A NAME="rpc_cmsd_version">
<HTML>
<HEAD>
<TITLE>Tutorial - Calendar Manager Version</TITLE>
</HEAD>
<BODY>

<H1>Calendar Manager Version</H1>

<HR>

<H3>Summary</H3>

rpc.cmsd:  A desktop calendar manager program, rpc.cmsd can 
be exploited through a buffer overflow attack.  Possibly, some patched 
versions are exploitable.

<H3>Impact</H3>

A remote intruder can execute commands as root if the buffer overflow
attack is successful.

<H3>The problem</H3>

The rpc.cmsd program (especially Solaris 2.5.x and 2.6, and IRIX 6.x)
is exploitable for remote root access.  Versions are vulnerable to a buffer
overflow attack where a well crafted pattern could execute arbitrary 
commands as the root user 

<H3>Fix</H3>

<ul>

<li>Where possible, disable rpc.cmsd in the <em>inetd.conf</em> file.

<li>Otherwise, patch the system to a version that is not vulnerable to
the buffer overflow attack. However, there are reports that even patched 
versions may be vulnerable.

</ul>

<H3>Other tips</H3>

<ul>

This vulnerability has not been reported to the public by any of the 
CERT organizations (as of 07/08/99).
</ul>
</BODY>
</HTML>
<HR>
<A NAME="rpc_rstatd_access">
<HTML>
<HEAD>
<TITLE>Tutorial - Rusersd/Rstatd Vulnerability</TITLE>
</HEAD>
<BODY>

<H1>Rusersd/Rstatd Vulnerability</H1>

<H3><u>Impact</u></H3>

These programs can provide the hacker with valuable information concerning
system activity and user population.  Please refer to the
<A HREF="rstatd_vulnerability.html">rstatd</a> and
<A HREF="rusersd_vulnerability.html">rusersd</a> vulnerabilities.
</BODY>
</HTML>
<HR>
<A NAME="rpc_statd_access">
<HTML>
<HEAD>
<TITLE>Tutorial - RPC.STATD access</TITLE>
</HEAD>
<BODY>

<H1>rpc.statd access</H1>

<HR>

<H3>Summary</H3>

rpc.statd:  The NFS support program, rpc.statd can be exploited through
a buffer overflow attack.

<H3>Impact</H3>

A remote intruder can execute commands as root if the buffer overflow
attack is successful.

<H3>The problem</H3>

The rpc.statd program is a support program to NFS which supports file
locking when requested.  Older versions of statd are vulnerable to a buffer
overflow attack where a well crafted pattern could execute arbitrary 
commands as the root user 

<H3>Fix</H3>

<ul>

<li>Where possible (i.e., not using NFS), disable rpc.statd in either
the <em>inetd.conf</em> or in one of the rc.d "S" files.

<li>Otherwise, patch the system to a version that is not vulnerable to
the buffer overflow attack.

</ul>

<H3>Other tips</H3>

<ul>

Refer to the
<A HREF="http://www.ciac.org/ciac/bulletins.i-017a.shtml">CIAC Bulletin</A>
for details.

</ul>
</BODY>
</HTML>
<HR>
<A NAME="rstatd_vulnerability">
<HEAD>
<TITLE>Tutorial - Rstatd vulnerability</TITLE>
</HEAD>
<BODY>

<H1>Rstatd Vulnerability</H1>
<P>
<HR>
<P>
<H3>Summary</H3>

rstatd:  This rpc process provides information  on a coputer's performance.

<H3>Impact</H3>

A hacker could determine trends on system utilization to pre-plan his
attack.

<H3>Problem</H3>

The rstatd replies to a query with information about the computer'sperformance.
By default, this function is available to all network users regardless of 
access privilege.  It provides the hacker with an excellant tool to detrmine
the best (i.e., least busy) time to do his work.

<H3>Resolution</H3>
<UL>
<LI> If possible, disable rstatd in inetd.conf or in one of the rc.d S*
files.  This may be problematic in SUN environments where the permeter
is used. Perfmeter requires rstatd, even if the performance monitoring 
is local.
<P>
<LI> If disabling is an issues, configure the portmapper to allow only
requests from "friendly sites".

</BODY>
</HTML>
<HR>
<A NAME="rusersd_vulnerability">
<HEAD>
<TITLE>Tutorial - Rusersd Vulnerability</TITLE>
</HEAD>
<BODY>

<H1>Rusersd Vulnerability</H1>
<P>
<HR>
<P>
<H3>Summary</H3>

The rusersd process provides a list of users logged on to the computer in
a format similar to the local "w" command.  This information may be valuable
to the hacker since it gives hime positive evidence of user activity.  
Normally, the hacker would wait until everyone is looged off before we "goes
to work".

<H3>Impact</H3>

The rusersd program can be a valuable tool since it informs him when
"nobody is around".


<H3>The Problem</H3>

The rusersd program provides useful information to the hacker in the
form of
<UL>
<P>
<LI>when activity is at a low point where the chances of being caught
are minimized 
<P>
<LI>providing information on valid user names
<P>
<LI>getting information while minimizing the chances of getting caught.
</UL>

<H3>Resolution</H3>
<P>
This vulnerability can be eliminated by:
<UL>
<LI>Eliminating this service by modifying the inetd configuration file
or 
<P>
<LI>removing a standalone daemon by editing the appropriate /etc/rc.d/S*
file.
</UL>
</BODY>
</HTML>
<HR>
<A NAME="sadmind_version">
<HTML>
<HEAD>
<TITLE>Tutorial - Sadmind Version</TITLE>
</HEAD>
<BODY>

<H1>Sadmind Version</H1>

<HR>

<H3>Summary</H3>

sadmind:  A Solstice administrator support program, sadmind can 
be exploited through a buffer overflow attack.  Possibly, some patched 
versions are exploitable.

<H3>Impact</H3>

A remote intruder can execute commands as root if the buffer overflow
attack is successful.

<H3>The problem</H3>

The sadmind program (especially Solaris 2.4, 2.5.x and 2.6)
is exploitable for remote root access.  Versions are vulnerable to a buffer
overflow attack where a well crafted pattern could execute arbitrary 
commands as the root user. 

<H3>Fix</H3>

<ul>

<li>Where possible, disable sadmind in the <em>inetd.conf</em> file.

<li>Otherwise, patch the system to a version that is not vulnerable to
the buffer overflow attack. However, there are reports that even patched 
versions may be vulnerable.

</ul>

<H3>Other tips</H3>

<ul>

CERT released <A HREF="http://www.cert.org/advisories/CA-99-16-sadmind.html">
CA-99-16</A> advisory on this topic.

</ul>
</BODY>
</HTML>
<HR>
<A NAME="sendmail_version">
<HTML>
<HEAD>
<TITLE>Tutorial - Sendmail vulnerabilities</TITLE>
</HEAD>
<BODY>

<H1>Sendmail vulnerabilities</H1>

<HR>

<H3>Summary</H3>

Assorted sendmail vulnerabilities.

<H3>The problems</H3>

With almost every sendmail version that was built before February 1998,
a malicious user can gain unauthorized privileges by exploiting
newlines in command-line arguments or in the process environment or in
buffer overflow attacks.  Intruders need to have access to an account on 
your system to exploit this problem.

<p>
<H3>Fix</H3>

<ul>

<li>Replace sendmail by a more recent version, for example from <a
href="http://www.sendmail.org">
www.sendmail.org</a>, or use a corrected version from
your vendor.

<li>Follow vendor instructions in the numerous advisories from
<A HREF="http://www.cert.org/advisories">CERT</A>
</ul>

<H3>Other tips</H3>

<ul>

<li>See the
<a href="http://www.clark.net/pub/arccom/stuff/admin_guide_to_cracking.html#sendmail">Admin
Guide to Cracking</a> for an example of why this is a problem.
 
</ul>
</BODY>
</HTML>
<HR>
<A NAME="tooltalk_version">
<HTML>
<HEAD>
<TITLE>Tutorial - Tooltalk Version</TITLE>
</HEAD>
<BODY>

<H1>Tooltalk Version</H1>

<HR>

<H3>Summary</H3>

rpc.ttdbserverd:  A desktop manager support program, rpc.ttdbserverd can 
be exploited through a buffer overflow attack.  Possibly, some patched 
versions are exploitable.

<H3>Impact</H3>

A remote intruder can execute commands as root if the buffer overflow
attack is successful.

<H3>The problem</H3>

The rpc.ttdbserverd program (especially Solaris 2.5.x and 2.6, and IRIX 6.x)
is exploitable for remote root access.  Versions are vulnerable to a buffer
overflow attack where a well crafted pattern could execute arbitrary 
commands as the root user 

<H3>Fix</H3>

<ul>

<li>Where possible, disable rpc.ttdbserverd in the <em>inetd.conf</em> file.

<li>Otherwise, patch the system to a version that is not vulnerable to
the buffer overflow attack. However, there are reports that even patched 
versions may be vulnerable.

</ul>

<H3>Other tips</H3>

<ul>

Refer to the
<A HREF="http://ciac.llnl.gov/ciac/bulletins/i-091.shtml">CIAC Bulletin</A>
for details.

</ul>
</BODY>
</HTML>
<HR>
<A NAME="unprotected_account">
<HEAD>
<TITLE>Tutorial - Unprotected account</TITLE>
</HEAD>
<BODY>

<H1>Unprotected Account</H1>

<HR>

<H3>Summary</H3>

Accounts with simple or no passwords.

<H3>Impact</H3>

A unauthorized user could gain access to the system.

<H3>Problem</H3>

Some system accounts such as sync, lp, or guest may not have passwords.  
The hacker can gain access to the system if he exploits one of these
accounts.  Further, once inside, the hacker may gain root access by
employing a local exploit.

<H3>Fix</H3>

<ul>

<li> Remove the account from the system and/or passwd file.

<li> Disable these accounts by (1) disabling login, (2) setting
the home directory to /dev/null, or (3) setting the default
shell to /bin/false.
</ul>

</BODY>
</HTML>
<HR>
<A NAME="unrestricted_NFS_export">
<HTML>
<HEAD>
<TITLE>Tutorial - Unrestricted NFS export</TITLE>
</HEAD>
<BODY>

<H1>Unrestricted NFS export</H1>

<HR>

<H3>Summary</H3>

File systems exported via NFS to arbitrary hosts.

<H3>Impact</H3>

Unauthorized remote access to system and/or user files.

<H3>The problem</H3>

When a file system is exported without restriction, an intruder can
remotely compromise user or system files, and then take over the
machine.  Examples:

<ul>

<li>An intruder can remotely replace a system program or configuration
file.

</ul>

UNIX-specific examples:

<ul>

<li>An intruder can remotely install a <em> .rhosts</em> file to
obtain interactive access.

<li>An intruder can remotely install a <em> .forward</em> file to
obtain non-interactive access.

</ul>

<H3>Fix</H3>

<ul>

<li>Make sure all file exports specify an explicit list of clients or
netgroups.

<li>Export file systems read-only where possible.

</ul>

<H3>Other tips</H3>

<ul>

<li>Some versions of the NFS mount daemon cannot expand large
netgroups and will export to the world anyway; see also <a
href="ftp://ftp.cert.org:/pub/cert_advisories/CA-94:02.REVISED.SunOS.rpc.mountd.vulnerability">
Cert advisory CA-94:02</a>.  Check your vendor patch list.

<li>In NIS netgroup members, empty host fields are treated as
wildcards and cause the mount daemon to grant access to any host.

<li>Consider blocking ports 2049 (nfs) and 111 (portmap) on your
routers.

<li>See the
<a href="http://www.clark.net/pub/arccom/stuff/admin_guide_to_cracking.html#unrestricted-NFS-export">Admin
Guide to Cracking</a> for an example of why this is a problem.

</ul>
</BODY>
</HTML>
<HR>
<A NAME="unrestricted_X_server_access">
<HTML>
<HEAD>
<TITLE>Tutorial - X server access</TITLE>
</HEAD>
<BODY>

<H1> X server access</H1>

<HR>

<H3>Summary</H3>

X server access from arbitrary hosts.

<H3>Impact</H3>

A remote intruder can control the keyboard, mouse and screen.

<H3>Background</H3>

The X Window system implements an environment where applications use
the network to interact with a user workstation's display, keyboard and
mouse. There are two classes of programs:

<ul>

<li>The X server: the program that manages the user's workstation
display and input devices.

<li>X clients: the applications that run on the user's workstation or
elsewhere in the network.

</ul>

<H3>The problem</H3>

When the X server permits access from arbitrary hosts on the network, a
remote intruder can connect to the X server and:

<ul>

<li>Read the user's keyboard, including any passwords that the user
types,

<li>Read everything that is sent to the screen,

<li>Write arbitrary information to the screen,

<li>Start or terminate arbitrary applications,

<li>Take control of the user's session.

</ul>

<H3>Fix</H3>

Remove all instances of the <em> xhost +</em> command from the
system-wide <em> Xsession</em> file, from user <em> .xsession</em>
files, and from any application programs or shell scripts that use the
X window system.

</ul>

<H3>Other tips</H3>

<ul>

<li>Use the X magic cookie mechanism or equivalent. With logins under
control of <em> xdm</em>, you turn on authentication by editing the
<em> xdm-config</em> file and setting <em> the
DisplayManager*authorize</em> attribute to <em> true</em>.

<li>When granting access to the screen from another machine, use the
<em> xauth</em> command in preference to the <em> xhost</em>
command.

<li>See the
<a href="http://www.clark.net/pub/arccom/stuff/admin_guide_to_cracking.html#x-access">Admin
Guide to Cracking</a> for an example of why this is a problem.
 
</ul>
</BODY>
</HTML>
<HR>
<A NAME="unrestricted_modem">
<HTML>
<HEAD>
<TITLE>Tutorial - Unrestricted Modem on the Internet</TITLE>
</HEAD>
<BODY>

<H1> Unrestricted Modem on the Internet</H1>

<HR>

<H3>Summary</H3>

A live and potentially unrestricted modem has been detected.

<H3>Impact</H3>

A remote intruder can anonymously dial anywhere that the
phone can call.

<H3>Background</H3>

In the past, dialout modems were often placed unprotected on one of a
UN*X host's TCP ports to facilitate their use.  With the advent of
special purpose hardware with built-in protection facilities, as well
as extra authentication methods such as S/Key and digital tokens,
there is little reason to do this.

<H3>The problem</H3>

Anyone can use the modem to dial anywhere, enabling them to attack
random targets and incurring you a potentially large phone bill.

<H3>Fix</H3>

Disallow unprotected Internet access of the modem by placing it behind a
firewall or putting password or other extra authentication methods on
it (such as S/Key or digital tokens.)

</BODY>
</HTML>
<HR>
<A NAME="unrestricted_smb_access">
<HTML>
<HEAD>
<TITLE>Tutorial - Unrestricted SMB Access</TITLE>
</HEAD>
<BODY>

<H1>Unrestricted SMB Access</H1>

<HR>

<H3>Summary</H3>

Server Message Block (SMB) files shares are world accessable.

<H3>Impact</H3>


<H3>The Problem</H3>

This vulnerability allows hackers to access files that have been "shared"
to the world without the need of a password or special account.

<H3>Fix</H3>

Confirm that there are no open shares that allow universal access.  This
is true for Microsoft Windows and Unix operating SAMBA.
</BODY>
</HTML>
<HR>
<A NAME="writable_FTP_home_directory">
<HTML>
<HEAD>
<TITLE>Tutorial - writable FTP home directory</TITLE>
</HEAD>
<BODY>

<H1>Writable FTP home directory</H1>

<HR>

<H3>Summary</H3>

FTP home directory is writable for anonymous users.

<H3>Impact</H3>

Remote command execution, remote file substitution.

<H3>The problem</H3>

When the FTP home directory of a UNIX host is writable, a remote
intruder can upload a <em>.rhosts</em> or <em>.forward</em> file to
gain access to the system, or may be able to replace files.

<p>

When a PC (DOS or MAC) permits anonymous users write access to its file
system, a remote intruder may be able replace arbitrary programs or
configuration files, or corrupt the file system by filling it up.

<H3>Fix (UNIX)</H3>

<ul>

<li>Make sure that the FTP home directory, and all system
files and directories below it, are owned by <em>root</em>.

<li>Make
sure that they are not writable by anonymous users. As a rule, no file
or directory should be owned by the FTP account.

</ul>

<H3>Other tips (UNIX)</H3>

<ul>

<li>Change the login shell of the ftp account to <tt>/bin/false</tt>.

<li>See the
<a href="http://www.clark.net/pub/arccom/stuff/admin_guide_to_cracking.html#writable-ftp">
Admin Guide to Cracking</a> for an example of why this is a problem.

<li><a href="ftp://ftp.cert.org/pub/tech_tips/anonymous_ftp">CERT/CC
Anomymous FTP configuration guidelines</a>.

</ul>
</BODY>
</HTML>
<HR>
EOF
